@@ -12,7 +12,7 @@ pub trait DispatchWidget: glib::IsA<gtk::Widget> {
             &format!("app.{}", action),
             argument.map(|a| a.to_variant()).as_ref(),
         ) {
-            error!("Send action {:?}", e);
+            error!("Dispatch action '{}': {}", action, e.to_string());
         }
     }
 }
